def gray(text):
    return f"\u001b[90m{text}\u001b[0m"

def red(text):
    return f"\u001b[31m{text}\u001b[0m"

def cyan(text):
    return f"\u001b[36m{text}\u001b[0m"

def green(text):
    return f"\u001b[32m{text}\u001b[0m"

def yellow(text):
    return f"\u001b[33m{text}\u001b[0m"


import os
from ..utils.terminal import red, gray

class Gemini:
    def __init__(self, model_name: str, generation_config):
        self.api_key = os.getenv("DOCGENIE_MODEL_API_KEY")
        if self.api_key is None or self.api_key == "":
            print(red("Gemini API key not found. Please set DOCGENIE_MODEL_API_KEY in the environment variables as your Gemini API key."))
            exit(1)
        self.model_name = model_name
        self.generation_config = generation_config

        self.loadModel()
        
    def loadModel(self):
        try:
            import google.generativeai as genai
            genai.configure(api_key=self.api_key)
            self.model = genai.GenerativeModel(
                model_name=self.model_name,
                generation_config=self.generation_config,
            )
        except ImportError:
            print(red("Please install the dependencies by running the following commands:\n"))
            print(gray("pip install google-generativeai"))
            print()
            exit(1)
        except Exception as e:
            print(red("Error loading Gemini model: {str(e)}"))
            exit(1)

    def generateContent(self, prompt: str = "") -> str:
        response = self.model.generate_content(prompt).text
        return response


import os
from ..utils.terminal import red, gray

class CustomAPI:
    def __init__(self, model_name: str, generation_config):
        self.api_key = os.getenv("DOCGENIE_MODEL_API_KEY")
        self.model_name = model_name
        self.generation_config = generation_config

        self.loadModel()
        
    def loadModel(self):
        try:
            import requests

            headers = self.generation_config.get("headers", {})
            query_params = self.generation_config.get("query", {})
            api_url = self.generation_config.get("url", "")
            
            # replace {DOCGENIE_MODEL_API_KEY} with the actual API key
            for key, value in headers.items():
                headers[key] = value.replace("{DOCGENIE_MODEL_API_KEY}", self.api_key)
            for key, value in query_params.items():
                query_params[key] = value.replace("{DOCGENIE_MODEL_API_KEY}", self.api_key)
            api_url = api_url.replace("{DOCGENIE_MODEL_API_KEY}", self.api_key)

            self.headers = headers
            self.query_params = query_params
            self.api_url = api_url

        except ImportError:
            print(red("Please install the dependencies by running the following commands:\n"))
            print(gray("pip install requests"))
            print()
            exit(1)
        except Exception as e:
            print(f"\u001b[31mError loading Custom API model: {str(e)}\u001b[0m")
            exit(1)

    def generateContent(self, prompt: str = "") -> str:
        import requests
        response = requests.get(self.api_url, headers=self.headers, params=self.query_params)
        response = response.text
        return response